/** Filter blastp output based on coverage and identity percentage
/**/

process REMOVE_LOOPS {

    input:
    path blastp

    output:
    path 'noloops.blastp.tsv'

    script:

    """
    awk 'BEGIN { FS=OFS="\t" }  \$1 != \$2 { print \$0 }'
    """
}

process ADD_GENE_ID_AND_PROTEIN_LENGTHS {

    input:
    path blastp
    path protein_length

    output:
    path 'joined.blastp.tsv'

    script:
    """
    sort -k 1 "${blastp}" > blastp_s
    sort -k 1 "${protein_length}" > protein_length_s
    join -1 1 -2 1 -t \$'\t' blastp_s protein_length_s > join1.tsv
    sort -k 2 join1.tsv > join1.tsv_s
    join -1 2 -2 1 -t \$'\t' join1.tsv_s protein_length_s > joined.blastp.tsv
    """

}

process FILTER_COVERAGE_IDENTITY_BLASTP {

    input:
    val min_coverage
    val min_identity
    path blastp

    output:
    path 'filtered.blastp.tsv'

    script:
    """
    awk -f "${baseDir}/scripts/filter_blastp.awk" \
        -v coverage="${min_coverage}" \
        -v identity="${min_identity}" \
        "${blastp}" > 'filtered.blastp.tsv'
    """
}

workflow FILTER_BLASTP {
    take:
    blastp
    protein_length
    min_coverage
    min_identity

    main:
    REMOVE_LOOPS(blastp)
    ADD_GENE_ID_AND_PROTEIN_LENGTHS(REMOVE_LOOPS.out)
    FILTER_COVERAGE_IDENTITY_BLASTP(min_identity, min_coverage, ADD_GENE_ID_AND_PROTEIN_LENGTHS.out)

    emit:
    blastp=FILTER_COVERAGE_IDENTITY_BLASTP
}
